@@ -8,18 +8,24 @@ add_stratification <- function (dat, strat, verbose = FALSE) {
     dat$strat <- 1
   } else {
     if (all(strat %in% colnames(dat))) {
-      dat$strat <- ""
-      for(i in seq(strat)) {
-        if(i > 1) { 
-          dat$strat <- paste0(dat$strat, ", ")
-        }
-        dat$strat <- paste0(dat$strat, data.frame(dat)[,strat[i]])
-      }      
+      if(length(strat) == 1) {
+        dat$strat <- data.frame(dat)[,strat]
+      } else {
+        dat$strat <- ""
+        for(i in seq(strat)) {
+          if(i > 1) { 
+            dat$strat <- paste0(dat$strat, ", ")
+          }
+          dat$strat <- paste0(dat$strat, data.frame(dat)[,strat[i]])
+        }      
+      }
     } else {
       dat$strat <- 1      
       msg("Specified stratification column name not found, not performing stratification.", verbose)
     }
-  }  
-  dat$strat <- as.factor(dat$strat)
+  }
+  if(class(dat$strat) != "factor") {
+    dat$strat <- as.factor(dat$strat)
+  }
   return(dat)
 }
